@@ -97,13 +97,19 @@ setAs('Raster', 'SpatialGridDataFrame',
 
 # To sp vector objects	
 
+setAs('RasterLayer', 'SpatialPolygons', 
+	function(from){ 
+		r <- rasterToPolygons(from)
+		as(r, 'SpatialPolygons')
+	}
+)
+
 setAs('RasterLayer', 'SpatialPolygonsDataFrame', 
 	function(from){ 
 		return( rasterToPolygons(from)) 
 	}
 )
 
-
 setAs('Raster', 'SpatialPoints', 
 	function(from) { 
 		SpatialPoints(rasterToPoints(from, spatial=FALSE)[,1:2], proj4string=projection(from, FALSE))
