@@ -5,26 +5,6 @@
 # Licence GPL v3
 
 
-.intSetNA <- function(v, dtype) {
-	if (dtype == 'INT1S') {
-		v[v < -127 | v > 128] <- NA
-	} else if (dtype == 'INT1U') {
-		v[v <=0 | v > 256] <- NA
-	} else  if (dtype == 'INT2S') {
-		v[v < -32767 | v > 32768] <- NA
-	} else  if (dtype == 'INT2U') {
-		v[v <= 0 | v > 65534] <- NA
-	} else if (dtype == 'INT4S') {
-		v[v < -2147483647 | v > 2147483648] <- NA
-	} else if (dtype == 'INT8S') {
-		v[v < -2^63/2 | v > 2^64/2] <- NA
-	} 
-	return(v)
-}
-
-
-
-
 .checkIntDataType <- function(mn, mx, dtype) {
 	mn <- round(mn)
 	mx <- round(mx)
@@ -51,10 +31,14 @@
 		if (mn < -2147483647 | mx > 2147483648 ) {
 			ok <- FALSE
 		}
-	} else if (dtype == 'INT8S') {
-		if (mn < -2^63/2 | mx > 2^64/2) {
+	} else if (dtype == 'INT4U') {
+		if (mn < 0 | mx > 2^32 ) {
 			ok <- FALSE
 		}
+#	} else if (dtype == 'INT8S') {
+#		if (mn < -2^63/2 | mx > 2^64/2) {
+#			ok <- FALSE
+#		}
 	} else {
 		stop('unknown integer type:', dtype)
 	}
@@ -78,8 +62,10 @@
 		datatype <- 'INT2U'
 	} else if (mn > -2147483647 & mx < 2147483648 ) {
 		datatype <- 'INT4S'
-	} else if (mn > -(2^63/2) & mx < (2^64/2)) {
-		datatype <- 'INT8S'
+	} else if (mn > 0 & mx < 2^32 ) {
+		datatype <- 'INT4U'
+##	} else if (mn > -(2^63/2) & mx < (2^64/2)) {
+#		datatype <- 'INT8S'
 	} else {
 		stop('these values are too large to be saved as integers')
 	}
@@ -87,3 +73,22 @@
 }
 
 
+
+..intSetNA <- function(v, dtype) {
+	if (dtype == 'INT1S') {
+		v[v < -127 | v > 128] <- NA
+	} else if (dtype == 'INT1U') {
+		v[v <=0 | v > 256] <- NA
+	} else  if (dtype == 'INT2S') {
+		v[v < -32767 | v > 32768] <- NA
+	} else  if (dtype == 'INT2U') {
+		v[v <= 0 | v > 65534] <- NA
+	} else if (dtype == 'INT4S') {
+		v[v < -2147483647 | v > 2147483648] <- NA
+	} else if (dtype == 'INT8S') {
+		v[v < -2^63/2 | v > 2^64/2] <- NA
+	} 
+	return(v)
+}
+
+
