@@ -196,20 +196,19 @@ projectRaster <- function(from, to, res, crs, method="bilinear", filename="", ..
 	} else {
 		to <- brick(to, values=FALSE, nl=nl)
 	}
-	layerNames(to) <- layerNames(from)
+	names(to) <- names(from)
 	if ( ! hasValues(from) ) {
 		warning("'from' has no cell values")
 		return(to)
 	}
 	
-	if (canProcessInMemory(to, n=nl*2)) {
+	if (canProcessInMemory(to, n=nl*4)) {
 		inMemory <- TRUE
 	} else {
 		inMemory <- FALSE
 	}
 
-	
-	
+		
 	if (.doCluster()) {
 		
 		cl <- getCluster()
@@ -300,10 +299,15 @@ projectRaster <- function(from, to, res, crs, method="bilinear", filename="", ..
 			xy <- .Call("transform", projto, projfrom, nrow(xy), xy[,1], xy[,2], PACKAGE="rgdal")
 			xy <- cbind(xy[[1]], xy[[2]])
 			to[cells] <- .xyValues(from, xy, method=method)
+			
+			if (filename != '') {
+				to <- writeRaster(to, filename, ...)
+			}	
 			return(to)
 			
 		} else {
-			tr <- blockSize(to)
+		
+			tr <- blockSize(to, n=nlayers(to)*4)
 			pb <- pbCreate(tr$n, ...)	
 			to <- writeStart(to, filename=filename, ...)
 			for (i in 1:tr$n) {
@@ -315,7 +319,7 @@ projectRaster <- function(from, to, res, crs, method="bilinear", filename="", ..
 					xy <- .Call("transform", projto, projfrom, nrow(xy), xy[,1], xy[,2], PACKAGE="rgdal")
 					xy <- cbind(xy[[1]], xy[[2]])
 					v <- matrix(nrow=length(cells), ncol=nl)
-					v[ci, ] <- .xyValues(from, xy, method=method)
+					v[ci, ] <- raster:::.xyValues(from, xy, method=method)
 					to <- writeValues(to, v, tr$row[i])
 				}	
 				pbStep(pb)
