@@ -10,21 +10,34 @@ if (!isGeneric("subs")) {
 }
 
 
-.localmerge <- function(x, y, subNA) {
-	nc <- NCOL(x)
-	nr <- NROW(x)
-	x <- cbind(1:length(x), as.vector(x))
-	if (! subNA ) {
-		y <- merge(x, y, by.x=2, by.y=1)
-		x[y[,2], 2] <- y[,3]
-		x <- x[,2]
+.localmerge <- function(x, y, subNA, byc=1) {
+	
+	if (byc==1) {
+		nc <- NCOL(x)
+		nr <- NROW(x)
+		x <- cbind(1:length(x), as.vector(x))
+		if (! subNA ) {
+			y <- merge(x, y, by.x=2, by.y=1)
+			x[y[,2], 2] <- y[,3]
+			x <- x[,2]
+			if (nc > 1) {
+				x <- matrix(as.vector(x), nrow=nr)
+			}
+		} else {
+			x <- as.matrix(merge(x, y, by.x=2, by.y=1, all.x=TRUE))
+			x <- x[order(x[,2]), -c(1:2)]
+		}
+		if (nc > 1) {
+			x <- matrix(as.vector(x), nrow = nr)
+		}
+
 	} else {
-		x <- as.matrix(merge(x, y, by.x=2, by.y=1, all.x=TRUE))
-		x <- x[order(x[,2]), -c(1:2)]
-	}	
-	if (nc > 1) {
-		x <- matrix(as.vector(x), nrow=nr)
+		x <- cbind(1:nrow(x), x)
+		x <- as.matrix(merge(x, y, by.x=(1:byc)+1, by.y=1:byc, all.x=TRUE))
+		x <- x[, -(1:byc)]
+		x <- x[order(x[,1]), -1]
 	}
+
 	return(x)
 }
 
@@ -32,28 +45,40 @@ if (!isGeneric("subs")) {
 setMethod('subs', signature(x='Raster', y='data.frame'), 
 	function(x, y, by=1, which=2, subsWithNA=TRUE, filename='', ...)  { 
 
-		if (!subsWithNA & length(which) > 1) {
-			stop('you cannot use subsWithNA=FALSE if length(which) > 1')
+		
+		if (!subsWithNA) {
+			if (length(which) > 1) {
+				stop('you cannot use subsWithNA=FALSE if length(which) > 1')
+			}
+			if (length(by) > 1) {
+				stop('you cannot use subsWithNA=FALSE if length(by) > 1')
+			}			
 		}
 		
+		stopifnot(length(by) == 1 | length(by) == nlayers(x))
+		
 		if (is.character(by)) {
-			by <- which(by == colnames(y))[1]
-			if (is.na(by)) { stop("'by' is not a valid column name") }
+			by <- match(by, colnames(y))
+			if (any(is.na(by))) {
+				stop("'by' is not a valid column name") 
+			}
 		}
 		if (is.character(which)) {
 			which <- which(which == colnames(y))[1]
 			if (is.na(which)) { stop("'which' is not valid column name") }
 		}
 		
+		byc <- length(by)
+		
 		y <- y[ , c(by, which)]
 
-		tt <- table(y[,1])
+		tt <- table(y[,by])
 		tt <- tt[ which(tt > 1) ]
 		if (length(tt) > 0) {
 			stop('duplicate "by" values not allowed')
 		}
 
-		r <- raster(x)
+		out <- raster(x)
 		nlx <- nlayers(x)
 		
 		cls <- sapply(y, class)
@@ -87,52 +112,59 @@ setMethod('subs', signature(x='Raster', y='data.frame'),
 		if (nlx == 1) {
 			ln <- colnames(y)[which]
 			if (length(which) > 1) {
-				r <- brick(r, nl=length(which))
+				out <- brick(out, nl=length(which))
 			}
 		} else {
-			r <- brick(r, nl=nlx * length(which))
-			ln <- rep(names(x), length(which))
-			if (length(which) > 1) {
-				ln2 <- rep(colnames(y)[which], each=nlx)
-				ln <- paste(ln, paste('_', ln2, sep=''), sep='')
-			}
+			if (byc == 1) {
+				out <- brick(out, nl=nlx * length(which))
+				ln <- rep(names(x), length(which))
+				if (length(which) > 1) {
+					ln2 <- rep(colnames(y)[which], each=nlx)
+					ln <- paste(ln, paste('_', ln2, sep=''), sep='')
+				}
+			} else {
+				if (length(which) > 1) {
+					out <- brick(out, nl=length(which))
+				}
+				ln <- colnames(y)[which]
+			} 
 		} 
-		names(r) <- ln
+		names(out) <- ln
 
 		filename <- trim(filename)
 		
 		if (canProcessInMemory(x, 3)) {
 			if (any(hasfactor)) {
-				r@data@isfactor <- hasfactor
-				r@data@attributes <- levs
+				out@data@isfactor <- hasfactor
+				out@data@attributes <- levs
 			}
-			v <- .localmerge( getValues(x), y, subsWithNA )
-			r <- setValues(r, v)
+			v <- .localmerge( getValues(x), y, subsWithNA, byc )
+			out <- setValues(out, v)
 			if (filename != '') {
-				r <- writeRaster(r, filename=filename, ...)
+				out <- writeRaster(out, filename=filename, ...)
 			}
-			return(r)
+			return(out)
 			
 		} else {
 			if (filename == '') {
 				filename <- rasterTmpFile()
 			}
-			tr <- blockSize(r)
+			tr <- blockSize(out)
 			pb <- pbCreate(tr$n, ...)
-			r <- writeStart(r, filename=filename, ...)
+			out <- writeStart(out, filename=filename, ...)
 			for (i in 1:tr$n) {
 				v <- getValues(x, row=tr$row[i], nrows=tr$nrows[i])
-				r <- writeValues(r, .localmerge(v, y, subsWithNA), tr$row[i])
+				out <- writeValues(out, .localmerge(v, y, subsWithNA, byc), tr$row[i])
 				pbStep(pb) 
 			}
 			pbClose(pb)	
 			
 			if (any(hasfactor)) {
-				r@data@isfactor <- TRUE
-				r@data@attributes <- levs
+				out@data@isfactor <- TRUE
+				out@data@attributes <- levs
 			}		
-			r <- writeStop(r)
-			return(r)
+			out <- writeStop(out)
+			return(out)
 		}
 	}
 )
